"""Sample entrypoint for template package."""

from typing import Literal


def placeholder_func() -> Literal[True]:  # always returns True
    """Sample function which returns True."""
    return True
